<?php

declare(strict_types=1);

namespace Drupal\bing_indexing_api\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Link;
use Drupal\Core\State\StateInterface;
use Drupal\Core\Url;
use Drupal\file\FileUsage\FileUsageInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides Bing Settings Form.
 */
class BingSettingsForm extends FormBase {

  /**
   * Constructs a new BingSettingsForm object.
   *
   * @param \Drupal\Core\State\StateInterface $state
   *   The State Service.
   * @param \Drupal\file\FileUsage\FileUsageInterface $fileUsage
   *   The file usage service.
   */
  public function __construct(protected StateInterface $state, protected FileUsageInterface $fileUsage) {
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): self {
    return new self(
      $container->get('state'),
      $container->get('file.usage')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'bing_index_api_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $form['top'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Settings'),
      '#collapsible' => FALSE,
      '#collapsed' => FALSE,
    ];

    $form['top']['bing_index_api_base_domain'] = [
      '#type' => 'textfield',
      '#title' => $this->t('The Base Domain of the site'),
      '#description' => $this->t('Provide the site domain.'),
      '#default_value' => $this->state->get('bing_index_api_base_domain'),
      '#required' => TRUE,
    ];

    $form['top']['bing_index_api_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('API key'),
      '#default_value' => $this->state->get('bing_index_api_key'),
      '#description' => $this->t('Follow @instruction_link to configure Bing and get API key.', [
        '@instruction_link' => Link::fromTextAndUrl($this->t('instruction'), Url::fromUri('https://learn.microsoft.com/en-us/bingwebmaster/getting-access#using-api-key'))
          ->toString(),
      ]),
      '#required' => TRUE,
    ];

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->state->set('bing_index_api_key', $form_state->getValue('bing_index_api_key'));
    $this->state->set('bing_index_api_base_domain', $form_state->getValue('bing_index_api_base_domain'));
  }

}
